import { AxiosInstance, Method, AxiosRequestConfig } from 'axios';
import type { Errors } from '..';
export interface ParametersType {
    [key: string]: any;
}
declare class BaseProxy {
    errors: Errors;
    parameters: any | any[];
    readonly endpoint: string;
    static $http: AxiosInstance | undefined;
    static $errorProperty: string;
    constructor(endpoint: string, parameters?: ParametersType);
    get $http(): AxiosInstance;
    get $errorProperty(): string;
    /**
     * Get all or by pagination
     */
    all<T>(): Promise<T>;
    /**
     * Alternative of all method
     */
    getMany<T>(): Promise<T>;
    /**
     * Find a record by id
     * @param {string|number} id
     */
    find<T>(id: number | string): Promise<T>;
    /**
     * Alternative of find method
     * @param {string | number} id
     */
    getOne<T>(id: number | string): Promise<T>;
    /**
     * Create record
     * @param {Object|string} payload
     * @param {AxiosRequestConfig} config
     */
    post<T>(payload: any, config?: AxiosRequestConfig): Promise<T>;
    /**
     * Alternative of post method
     * @param payload
     * @param {AxiosRequestConfig} config
     */
    store<T>(payload: any, config?: AxiosRequestConfig): Promise<T>;
    /**
     * Alternative of store method
     * @param payload
     * @param {AxiosRequestConfig} config
     */
    create<T>(payload: any, config?: AxiosRequestConfig): Promise<T>;
    /**
     * Create many items
     * @param {Object} payload
     */
    createMany<T>(payload: T): Promise<T>;
    /**
     * Update record by id using PUT method
     * @param {string|number} id
     * @param {Object|string} payload
     */
    put<T>(id: string | number, payload: any): Promise<T>;
    /**
     * Alternative of put method
     * @param {string|number} id
     * @param {Object|string} payload
     */
    replace<T>(id: string | number, payload: any): Promise<T>;
    /**
     * This method helpful for laravel developer
     * @param {string|number} id
     * @param {Object} payload
     * @param config
     */
    putWithFile<T>(id: string | number, payload: any, config?: AxiosRequestConfig): Promise<T>;
    /**
     * Update record by id
     * @param id
     * @param payload
     */
    patch<T>(id: string | number, payload: any): Promise<T>;
    /**
     * Alternative of path method
     * @param {string|number} id
     * @param {Object|string} payload
     */
    update<T>(id: string | number, payload: any): Promise<T>;
    /**
     * Delete record by id
     * @param {string|number} id
     */
    delete<T>(id: string | number): Promise<T>;
    /**
     * Alternative of delete method
     * @param {string|number} id
     */
    remove<T>(id: string | number): Promise<T>;
    /**
     * Main endpoint method to handle requests
     * @param requestType
     * @param {string} parameter
     * @param {Object|string} form
     * @param {AxiosRequestConfig} config
     */
    submit<T>(requestType: Method, parameter?: string | number, form?: T, config?: AxiosRequestConfig): Promise<T>;
    private __getParameterString;
    private static __validateRequestType;
    /**
     * Set parameters by keys
     * @param {Object} parameters
     */
    setParameters(parameters: ParametersType): this;
    /**
     * Set parameters by key
     * @param {string} parameter
     * @param {Object|string|Array} value
     */
    setParameter(parameter: string, value?: any): this;
    /**
     * Remove parameters by keys
     * @param {Array<Object>>} parameters
     */
    removeParameters(parameters?: any[]): this;
    /**
     * Remove parameters
     * @param {string} parameter
     */
    removeParameter(parameter: string): this;
    /**
     * Fill errors on fails passed
     * @param {Object} errors
     */
    onFail(errors: ParametersType): void;
    /**
     * Clean up errors and set processing
     */
    beforeSubmit(): void;
    /**
     * Clean up errors and set success on after request
     */
    onSuccess(): void;
}
export default BaseProxy;
